searchNodes=[{"doc":"Implementation of JSONPointer. This module handles JSONPointers as an internal term representation and provides functions to manipulate the JSONPointer term and to use the representation to traverse or manipulate JSON data. See: https://www.rfc-editor.org/rfc/rfc6901 for the specification. Warning Do not rely on the private internal implementation of JSONPointer, it may change in the future.","ref":"JsonPtr.html","title":"JsonPtr","type":"module"},{"doc":"rolls back the JsonPtr to the parent of its most distant leaf. iex&gt; { :ok , ptr } = &quot;/foo/bar&quot; |&gt; JsonPtr . from_path |&gt; JsonPtr . backtrack iex&gt; JsonPtr . to_path ( ptr ) &quot;/foo&quot;","ref":"JsonPtr.html#backtrack/1","title":"JsonPtr.backtrack/1","type":"function"},{"doc":"like backtrack/1 , but raises if attempted to backtrack from the root.","ref":"JsonPtr.html#backtrack!/1","title":"JsonPtr.backtrack!/1","type":"function"},{"doc":"Performs a each operation on the JSON data at the given pointer, analogous to Enum.each/2 . Returns :ok when all iterations are complete The iterator function will be passed the updated pointer and the data at that pointer. If you pass an arity 3 function, it will also pass the key (or index) of the data in addition to the JsonPtr. iex&gt; ptr = JsonPtr . from_path ( &quot;/foo&quot; ) iex&gt; JsonPtr . each ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , &amp; send ( self ( ) , { JsonPtr . to_path ( &amp;1 ) , &amp;2 } ) ) :ok iex&gt; receive do data -&gt; data end { &quot;/foo/0&quot; , &quot;bar&quot; } iex&gt; receive do data -&gt; data end { &quot;/foo/1&quot; , &quot;baz&quot; } iex&gt; JsonPtr . each ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , &amp; send ( self ( ) , { JsonPtr . to_path ( &amp;1 ) , &amp;2 , &amp;3 } ) ) :ok iex&gt; receive do data -&gt; data end { &quot;/foo/0&quot; , 0 , &quot;bar&quot; } iex&gt; receive do data -&gt; data end { &quot;/foo/1&quot; , 1 , &quot;baz&quot; }","ref":"JsonPtr.html#each/3","title":"JsonPtr.each/3","type":"function"},{"doc":"Performs a flat_map operation on the JSON data at the given pointer, analogous to Enum.flat_map/2 . If you pass an arity 3 function, it will also pass the key (or index) of the data in addition to the JsonPtr. The iterator function will be passed the updated pointer and the data at that pointer. iex&gt; ptr = JsonPtr . from_path ( &quot;/foo&quot; ) iex&gt; JsonPtr . flat_map ( ptr , %{ &quot;foo&quot; =&gt; %{ &quot;bar&quot; =&gt; &quot;baz&quot; } } , fn ptr , data -&gt; [ { JsonPtr . to_path ( ptr ) , data } ] end ) [ { &quot;/foo/bar&quot; , &quot;baz&quot; } ] iex&gt; JsonPtr . flat_map ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , fn ptr , data -&gt; [ { JsonPtr . to_path ( ptr ) , data } ] end ) [ { &quot;/foo/0&quot; , &quot;bar&quot; } , { &quot;/foo/1&quot; , &quot;baz&quot; } ]","ref":"JsonPtr.html#flat_map/3","title":"JsonPtr.flat_map/3","type":"function"},{"doc":"converts a path to a JsonPtr iex&gt; JsonPtr . from_path ( &quot;/&quot; ) # the root-only case [ ] iex&gt; JsonPtr . from_path ( &quot;/foo/bar&quot; ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPtr . from_path ( &quot;/foo~0bar/baz&quot; ) [ &quot;foo~bar&quot; , &quot;baz&quot; ] iex&gt; JsonPtr . from_path ( &quot;/currency/%E2%82%AC&quot; ) [ &quot;currency&quot; , &quot;€&quot; ]","ref":"JsonPtr.html#from_path/1","title":"JsonPtr.from_path/1","type":"function"},{"doc":"converts a URI (or a URI-string) to a JsonPtr. iex&gt; JsonPtr . from_uri ( &quot;#/foo/bar&quot; ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPtr . from_uri ( &quot;/foo/bar&quot; ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPtr . from_uri ( % URI { path : &quot;/foo/bar&quot; } ) [ &quot;foo&quot; , &quot;bar&quot; ] iex&gt; JsonPtr . from_uri ( % URI { fragment : &quot;/foo/bar&quot; , host : &quot;elixir-lang.org&quot; } ) [ &quot;foo&quot; , &quot;bar&quot; ]","ref":"JsonPtr.html#from_uri/1","title":"JsonPtr.from_uri/1","type":"function"},{"doc":"appends path to the JsonPtr. This may either be a t:String.t , a list of t:String.t . iex&gt; ptr = JsonPtr . from_path ( &quot;/foo/bar&quot; ) iex&gt; ptr |&gt; JsonPtr . join ( &quot;baz&quot; ) |&gt; JsonPtr . to_path &quot;/foo/bar/baz&quot; iex&gt; ptr |&gt; JsonPtr . join ( [ &quot;baz&quot; , &quot;quux&quot; ] ) |&gt; JsonPtr . to_path &quot;/foo/bar/baz/quux&quot;","ref":"JsonPtr.html#join/2","title":"JsonPtr.join/2","type":"function"},{"doc":"Performs a map operation on the JSON data at the given pointer, analogous to Enum.map/2 . The iterator function will be passed the updated pointer and the data at that pointer. If you pass an arity 3 function, it will also pass the key (or index) of the data in addition to the JsonPtr. iex&gt; ptr = JsonPtr . from_path ( &quot;/foo&quot; ) iex&gt; JsonPtr . map ( ptr , %{ &quot;foo&quot; =&gt; %{ &quot;bar&quot; =&gt; &quot;baz&quot; } } , &amp; { JsonPtr . to_path ( &amp;1 ) , &amp;2 } ) [ { &quot;/foo/bar&quot; , &quot;baz&quot; } ] iex&gt; JsonPtr . map ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , &amp; { JsonPtr . to_path ( &amp;1 ) , &amp;2 } ) [ { &quot;/foo/0&quot; , &quot;bar&quot; } , { &quot;/foo/1&quot; , &quot;baz&quot; } ] iex&gt; JsonPtr . map ( ptr , %{ &quot;foo&quot; =&gt; %{ &quot;bar&quot; =&gt; &quot;baz&quot; } } , &amp; { JsonPtr . to_path ( &amp;1 ) , &amp;2 , &amp;3 } ) [ { &quot;/foo/bar&quot; , &quot;bar&quot; , &quot;baz&quot; } ] iex&gt; JsonPtr . map ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , &amp; { JsonPtr . to_path ( &amp;1 ) , &amp;2 , &amp;3 } ) [ { &quot;/foo/0&quot; , 0 , &quot;bar&quot; } , { &quot;/foo/1&quot; , 1 , &quot;baz&quot; } ]","ref":"JsonPtr.html#map/3","title":"JsonPtr.map/3","type":"function"},{"doc":"returns the last part of the pointer and the pointer without it. iex&gt; { rest , last } = &quot;/foo/bar&quot; |&gt; JsonPtr . from_path |&gt; JsonPtr . pop iex&gt; last &quot;bar&quot; iex&gt; JsonPtr . to_path ( rest ) &quot;/foo&quot; iex&gt; &quot;/&quot; |&gt; JsonPtr . from_path |&gt; JsonPtr . pop :error","ref":"JsonPtr.html#pop/1","title":"JsonPtr.pop/1","type":"function"},{"doc":"Performs a reduction operation on the JSON data at the given pointer, analogous to Enum.reduce/3 . The iterator function will be passed the updated pointer, the data and the accumulator at that pointer. If you pass an arity 4 function, it will also pass the key (or index) of the data in addition to the JsonPtr. iex&gt; ptr = JsonPtr . from_path ( &quot;/foo&quot; ) iex&gt; JsonPtr . reduce ( ptr , %{ &quot;foo&quot; =&gt; %{ &quot;bar&quot; =&gt; &quot;baz&quot; } } , %{ } , &amp; Map . put ( &amp;3 , JsonPtr . to_path ( &amp;1 ) , &amp;2 ) ) %{ &quot;/foo/bar&quot; =&gt; &quot;baz&quot; } iex&gt; JsonPtr . reduce ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , %{ } , &amp; Map . put ( &amp;3 , JsonPtr . to_path ( &amp;1 ) , &amp;2 ) ) %{ &quot;/foo/0&quot; =&gt; &quot;bar&quot; , &quot;/foo/1&quot; =&gt; &quot;baz&quot; } iex&gt; JsonPtr . reduce ( ptr , %{ &quot;foo&quot; =&gt; %{ &quot;bar&quot; =&gt; &quot;baz&quot; } } , %{ } , &amp; Map . put ( &amp;4 , { JsonPtr . to_path ( &amp;1 ) , &amp;2 } , &amp;3 ) ) %{ { &quot;/foo/bar&quot; , &quot;bar&quot; } =&gt; &quot;baz&quot; } iex&gt; JsonPtr . reduce ( ptr , %{ &quot;foo&quot; =&gt; [ &quot;bar&quot; , &quot;baz&quot; ] } , %{ } , &amp; Map . put ( &amp;4 , { JsonPtr . to_path ( &amp;1 ) , &amp;2 } , &amp;3 ) ) %{ { &quot;/foo/0&quot; , 0 } =&gt; &quot;bar&quot; , { &quot;/foo/1&quot; , 1 } =&gt; &quot;baz&quot; }","ref":"JsonPtr.html#reduce/4","title":"JsonPtr.reduce/4","type":"function"},{"doc":"given some JSON data, resolves the content pointed to by the JsonPtr. Note the json pointer is the second parameter to this function. iex&gt; JsonPtr . resolve_json ( true , &quot;/&quot; ) { :ok , true } iex&gt; JsonPtr . resolve_json ( %{ &quot;foo~bar&quot; =&gt; &quot;baz&quot; } , &quot;/foo~0bar&quot; ) { :ok , &quot;baz&quot; } iex&gt; JsonPtr . resolve_json ( %{ &quot;€&quot; =&gt; [ &quot;quux&quot; , &quot;ren&quot; ] } , JsonPtr . from_path ( &quot;/%E2%82%AC/1&quot; ) ) { :ok , &quot;ren&quot; }","ref":"JsonPtr.html#resolve_json/2","title":"JsonPtr.resolve_json/2","type":"function"},{"doc":"given some JSON data, resolves the content pointed to by the JsonPtr. Note the json pointer is the second parameter to this function. iex&gt; JsonPtr . resolve_json! ( true , &quot;/&quot; ) true iex&gt; JsonPtr . resolve_json! ( %{ &quot;foo~bar&quot; =&gt; &quot;baz&quot; } , &quot;/foo~0bar&quot; ) &quot;baz&quot; iex&gt; JsonPtr . resolve_json! ( %{ &quot;€&quot; =&gt; [ &quot;quux&quot; , &quot;ren&quot; ] } , JsonPtr . from_path ( &quot;/%E2%82%AC/1&quot; ) ) &quot;ren&quot;","ref":"JsonPtr.html#resolve_json!/2","title":"JsonPtr.resolve_json!/2","type":"function"},{"doc":"creates a JsonPtr to its path equivalent. iex&gt; JsonPtr . to_path ( [ &quot;foo&quot; , &quot;bar&quot; ] ) &quot;/foo/bar&quot; iex&gt; JsonPtr . to_path ( [ &quot;foo~bar&quot; , &quot;baz&quot; ] ) &quot;/foo~0bar/baz&quot; iex&gt; JsonPtr . to_path ( [ &quot;currency&quot; , &quot;€&quot; ] ) &quot;/currency/%E2%82%AC&quot;","ref":"JsonPtr.html#to_path/1","title":"JsonPtr.to_path/1","type":"function"},{"doc":"creates a URI.t/0 struct out of a JsonPtr. The JsonPtr is placed in the :fragment field of the URI. iex&gt; JsonPtr . to_uri ( [ &quot;foo&quot; , &quot;bar&quot; ] ) % URI { fragment : &quot;/foo/bar&quot; }","ref":"JsonPtr.html#to_uri/1","title":"JsonPtr.to_uri/1","type":"function"},{"doc":"updates nested JSON data at the location given by the JsonPtr. iex&gt; ptr = JsonPtr . from_path ( &quot;/foo/0&quot; ) iex&gt; JsonPtr . update_json! ( %{ &quot;foo&quot; =&gt; [ 1 , 2 ] } , ptr , &amp; ( &amp;1 + 1 ) ) %{ &quot;foo&quot; =&gt; [ 2 , 2 ] } iex&gt; JsonPtr . update_json! ( %{ &quot;foo&quot; =&gt; %{ &quot;0&quot; =&gt; 1 } } , ptr , &amp; ( &amp;1 + 1 ) ) %{ &quot;foo&quot; =&gt; %{ &quot;0&quot; =&gt; 2 } }","ref":"JsonPtr.html#update_json!/3","title":"JsonPtr.update_json!/3","type":"function"},{"doc":"","ref":"JsonPtr.html#t:json/0","title":"JsonPtr.json/0","type":"type"},{"doc":"","ref":"JsonPtr.html#t:t/0","title":"JsonPtr.t/0","type":"opaque"}]